<?php

$LANG = array(

'L_ID' 								=> '#',
'L_MENU'							=> 'Menu',
'L_UNKNOWN_ERROR'					=> 'Nieznany błąd',
'L_CONFIRM_DELETE'					=> 'Na pewno chcesz usunąć ?',
'L_SAVE_FILE'						=> 'Zapisz plik',
'L_SAVE_FILE_SUCCESSFULLY'			=> 'Plik został pomyślnie zapisany',
'L_SAVE_FILE_ERROR'					=> 'Wystąpił błąd podczas zapisywania pliku',
'L_REPLY'							=> 'Odpowiedź',
'L_REPLY_TO'						=> 'Odpowiedź',
'L_CANCEL'							=> 'Anulować',
'L_DELETE' 						    => 'Usuń',
'L_DELETE_FILE' 				    => 'Usuń plik',
'L_DELETE_FOLDER'				    => 'Usuń folder',
'L_DELETE_SUCCESSFUL'				=> 'Skuteczne usuwanie',
'L_DELETE_FILE_ERR'					=> 'Błąd podczas usuwania pliku',
'L_RENAME_FILE_SUCCESSFUL'			=> 'Plik przemianowany powodzeniem',
'L_RENAME_FILE_ERR'					=> 'Błąd podczas przetwarzania pliku',
'L_RENAME_FILE'						=> 'Zmień nazwę pliku',
'L_THUMBNAIL'						=> 'Miniaturka (opcjonalnie)',
'L_THUMBNAIL_SELECTION'				=> 'Wybierz zdjęcie',
'L_THUMBNAIL_TITLE'					=> 'Tytuł zdjęcia (opcjonalnie)',
'L_THUMBNAIL_ALT'					=> 'Alternatywny tekst z obrazka (opcjonalnie)',
'L_ERR_INVALID_DATE_CREATION'		=> 'Nieprawidłowa data utworzenia',
'L_ERR_INVALID_DATE_UPDATE'			=> 'Nieprawidłowa data zaktualizowane',

# class.plx.admin.php

'L_SAVE_SUCCESSFUL'					=> 'Zapisywanie zakończone powodzeniem',
'L_SAVE_ERR'						=> 'Wystąpił błąd podczas zapisywania',
'L_NO_ENTRY'						=> 'Dostęp zabroniony',
'L_ERR_USER_EMPTY'					=> 'Wpisz nazwę użytkownika',
'L_ERR_PASSWORD_EMPTY'				=> 'Wpisz hasło',
'L_ERR_PASSWORD_EMPTY_CONFIRMATION'	=> 'Wystąpił błąd potwierdzenia hasła lub jest ono puste',
'L_ERR_INVALID_EMAIL'				=> 'Niepoprawny adres e-mail',
'L_ERR_INVALID_SITE'				=> 'Niepoprawny adres strony',
'L_ERR_INVALID_ARTICLE_IDENT'		=> 'Nieważny ID posta !',
'L_DEFAULT_NEW_CATEGORY_URL'		=> 'nowa-kategoria',
'L_DEFAULT_NEW_STATIC_URL'			=> 'nowa-strona',
'L_DEFAULT_NEW_ARTICLE_URL'			=> 'nowy-post',
'L_ARTICLE_SAVE_SUCCESSFUL'			=> 'Post został pomyślnie utworzony',
'L_ARTICLE_MODIFY_SUCCESSFUL'		=> 'Post został pomyślnie edytowany',
'L_ARTICLE_DELETE_SUCCESSFUL'		=> 'Post został pomyślnie usunięty',
'L_ARTICLE_SAVE_ERR'				=> 'Wystąpił błąd podczas zapisywania posta',
'L_ARTICLE_DELETE_ERR'				=> 'Wystąpił błąd podczas usuwania posta',
'L_ERR_UNKNOWN_COMMENT'				=> 'Wybrany komentarz już nie istnieje',
'L_COMMENT_SAVE_SUCCESSFUL'			=> 'Komentarz został pomyślnie zapisany',
'L_COMMENT_UPDATE_ERR'				=> 'Wystąpił błąd podczas aktualizacji komentarza',
'L_COMMENT_DELETE_SUCCESSFUL'		=> 'Komentarz został pomyślnie usunięty',
'L_COMMENT_DELETE_ERR'				=> 'Wystąpił błąd podczas usuwania komentarza',
'L_COMMENT_VALIDATE_SUCCESSFUL'		=> 'Walidacja zakończyła się powodzeniem',
'L_COMMENT_VALIDATE_ERR'			=> 'Wystąpił błąd podczas walidacji',
'L_COMMENT_MODERATE_SUCCESSFUL'		=> 'Komentarz został pomyślnie edytowany',
'L_COMMENT_MODERATE_ERR'			=> 'Wystąpił błąd podczas edycji komentarza',
'L_ERR_URL_ALREADY_EXISTS'			=> 'Adres URL jest używany. Proszę zmienić wartość pola URL',

# class.plx.media.php

'L_PLXMEDIAS_MEDIAS_FOLDER_ERR'		=> 'Wystąpił błąd podczas tworzenia folderu multimedialnego dla podłączonego użytkownika',
'L_PLXMEDIAS_ROOT'					=> 'główny',
'L_PLXMEDIAS_DELETE_FILES_SUCCESSFUL'=> 'Pliki zostały pomyślnie usunięte',
'L_PLXMEDIAS_DELETE_FILES_ERR'		=> 'Wystąpił błąd podczas usuwania plików',
'L_PLXMEDIAS_DELETE_FILE_SUCCESSFUL'=> 'Plik został pomyślnie usunięty',
'L_PLXMEDIAS_DELETE_FILE_ERR'		=> 'Wystąpił błąd podczas usuwania pliku',
'L_PLXMEDIAS_DEL_FOLDER_ERR'		=> 'Wystąpił błąd podczas usuwania folderu',
'L_PLXMEDIAS_DEL_FOLDER_SUCCESSFUL'	=> 'Folder został pomyślnie usunięty',
'L_PLXMEDIAS_NEW_FOLDER_ERR'		=> 'Wystąpił błąd podczas tworzenia folderu',
'L_PLXMEDIAS_NEW_FOLDER_SUCCESSFUL'	=> 'Folder został pomyślnie utworzony',
'L_PLXMEDIAS_NEW_FOLDER_EXISTS'		=> 'Folder o tej nazwie już istnieje',
'L_PLXMEDIAS_WRONG_FILESIZE'		=> 'Rozmiar pliku jest większy niż',
'L_PLXMEDIAS_WRONG_FILEFORMAT'		=> 'Ten typ pliku nie jest dozwolony',
'L_PLXMEDIAS_UPLOAD_ERR'			=> 'Wystąpił błąd podczas wysyłania pliku',
'L_PLXMEDIAS_UPLOAD_SUCCESSFUL'		=> 'Plik został pomyślnie wysłany',
'L_PLXMEDIAS_UPLOADS_ERR'			=> 'Wystąpił błąd podczas wysyłania plików',
'L_PLXMEDIAS_UPLOADS_SUCCESSFUL'	=> 'Pliki zostały pomyślnie wysłane',
'L_PLXMEDIAS_MOVE_FILES_SUCCESSFUL'	=> 'Pliki zostały pomyślnie przeniesione',
'L_PLXMEDIAS_MOVE_FILE_SUCCESSFUL'	=> 'Plik został pomyślnie przeniesiony',
'L_PLXMEDIAS_MOVE_FILES_ERR'		=> 'Wystąpił błąd podczas przenoszenia plików',
'L_PLXMEDIAS_MOVE_FILE_ERR'			=> 'Wystąpił błąd podczas przenoszenia pliku',
'L_PLXMEDIAS_MOVE_FOLDER'			=> 'Przenieś',
'L_PLXMEDIAS_RECREATE_THUMB_ERR'	=> 'Wystąpił błąd podczas tworzenia miniatury',
'L_PLXMEDIAS_RECREATE_THUMBS_ERR'	=> 'Wystąpił błąd podczas tworzenia miniatur',
'L_PLXMEDIAS_RECREATE_THUMB_SUCCESSFUL'	=> 'Miniatura została pomyślnie utworzona',
'L_PLXMEDIAS_RECREATE_THUMBS_SUCCESSFUL'=> 'Miniatury zostały pomyślnie utworzone',

# article.php

'L_DEFAULT_NEW_ARTICLE_TITLE'		=> 'Nowy post',
'L_ERR_INVALID_PUBLISHING_DATE'		=> 'Nieprawidłowa data publikacji',
'L_ERR_UNKNOWN_ARTICLE'				=> 'Post już nie istnieje !',
'L_ERR_FORBIDDEN_ARTICLE'			=> 'Nie masz dostępu do tego posta',
'L_BACK_TO_ARTICLES'				=> 'Przejdż do listy postów',
'L_ARTICLE_EDITING'					=> 'Edycja posta',
'L_ARTICLE_TITLE'					=> 'Tytuł',
'L_ARTICLE_LIST_AUTHORS'			=> 'Autor',
'L_HEADLINE_FIELD'					=> 'Nagłówek (opcjonalnie)',
'L_CONTENT_FIELD'					=> 'Treść',
'L_LINK_FIELD'						=> 'Link do posta',
'L_LINK_ACCESS'						=> 'Przejdź do posta',
'L_LINK_VIEW'						=> 'podgląd',
'L_ARTICLE_STATUS'					=> 'Status',
'L_DRAFT' 							=> 'Projekt',
'L_PUBLISHED' 						=> 'Opublikowany',
'L_AWAITING'						=> 'Oczekiwanie na zatwierdzenie',
'L_ARTICLE_DATE' 					=> 'Data publikacji',
'L_NOW'								=> 'teraz',
'L_ARTICLE_CATEGORIES' 				=> 'Kategoria',
'L_CATEGORY_HOME_PAGE' 			 	=> 'Strona główna',
'L_NEW_CATEGORY' 			 		=> 'Nowa kategoria',
'L_ARTICLE_TAGS_FIELD' 				=> 'Tagi',
'L_ARTICLE_TAGS_FIELD_TITLE' 		=> 'Tagi oddzielaj przecinkami',
'L_ARTICLE_TOGGLER_TITLE' 			=> 'Lista tagów',
'L_NO_TAG' 							=> 'Brak tagów',
'L_ALLOW_COMMENTS' 					=> 'Zezwól na komentarze',
'L_ARTICLE_URL_FIELD' 				=> 'URL',
'L_ARTICLE_URL_FIELD_TITLE' 		=> 'URL automatycznie wypełni pole gdy post zostanie utworzony',
'L_ARTICLE_TEMPLATE_FIELD' 			=> 'Szablon',
'L_ARTICLE_MANAGE_COMMENTS'			=> 'Zarządzaj komentarzami',
'L_ARTICLE_MANAGE_COMMENTS_TITLE'	=> 'Zarządzaj komentarzaami dla tego posta',
'L_ARTICLE_NEW_COMMENT'				=> 'Napisz komentarz',
'L_ARTICLE_NEW_COMMENT_TITLE'		=> 'Napisz komentarz dla tego posta',
'L_ARTICLE_DELETE_CONFIRM'			=> 'Usuń ten post ?',
'L_ARTICLE_PREVIEW_BUTTON'			=> 'Podgląd',
'L_ARTICLE_DRAFT_BUTTON' 			=> 'Zapisz projekt',
'L_ARTICLE_PUBLISHING_BUTTON'		=> 'Opublikuj',
'L_ARTICLE_MODERATE_BUTTON'			=> 'Prześlij do sprawdzania',
'L_ARTICLE_OFFLINE_BUTTON'			=> 'Deaktywuj',
'L_ARTICLE_UPDATE_BUTTON' 			=> 'Zapisz',
'L_CATEGORY_ADD_BUTTON'				=> "Dodaj",
'L_ARTICLE_META_DESCRIPTION'		=> 'Zawartość tagu "opisu" (opcjonalnie)',
'L_ARTICLE_META_KEYWORDS'			=> 'Zawartość tagu "słowa kluczowego" (opcjonalnie)',
'L_ARTICLE_TITLE_HTMLTAG'			=> 'Zawartość tagu "tytułu" (opcjonalnie)',
'L_ARTICLE_CHAPO_HIDE'				=> 'ukryj',
'L_ARTICLE_CHAPO_DISPLAY'			=> 'pokaż',
'L_ARTICLE'							=> 'post',
'L_ARTICLE_ID'						=> 'Identyfikator',

# auth.php

'L_AUTH_PAGE_TITLE'					=> 'administracja',
'L_LOGOUT_SUCCESSFUL'				=> 'Poprawne wylogowanie',
'L_LOGIN_PAGE'						=> 'Logowanie do panelu administracyjnego',
'L_AUTH_LOGIN_FIELD'				=> 'Login',
'L_AUTH_PASSWORD_FIELD'				=> 'Hasło',
'L_SUBMIT_BUTTON'					=> 'Zaloguj',
'L_ERR_WRONG_PASSWORD' 				=> 'Login i / lub hasło niepoprawne',
'L_POWERED_BY'						=> 'Silnik <a href="http://www.pluxml.org">PluXml</a>',
'L_ERR_MAXLOGIN'					=> 'Zbyt wielu nieudanych<br />ponownych prób logowania w% s minut',

#

'L_SORT_ASCENDING_DATE'				=> 'data rosnąca',
'L_SORT_DESCENDING_DATE'			=> 'data malejąco',
'L_SORT_ALPHABETICAL'				=> 'alfabetycznie',
'L_SORT_RANDOM'						=> '
przypadkowy',
'L_YES' 							=> 'Tak',
'L_NO' 								=> 'Nie',
'L_OK'								=> 'OK',
'L_NONE1'							=> 'brak',
'L_NONE2'							=> 'brak',

# categories.php

'L_CAT_TITLE'						=> 'Utworz lub edytuj kategorie',
'L_CAT_LIST_ID' 					=> 'ID',
'L_CAT_LIST_ACTIVE'					=> 'Aktywna',
'L_CAT_LIST_NAME' 					=> 'Nazwa kategorii',
'L_CAT_LIST_URL' 					=> 'URL',
'L_CAT_LIST_SORT' 					=> 'Sortowanie artykułów',
'L_CAT_LIST_BYPAGE'					=> 'Nr. artykułu/strony',
'L_CAT_LIST_ORDER' 					=> 'Kolejność',
'L_CAT_LIST_MENU' 					=> 'Menu',
'L_CATEGORY'						=> 'Kategoria',
'L_DISPLAY'							=> 'Pokaż',
'L_HIDE'							=> 'Ukryj',
'L_OPTIONS'							=> 'Opcje',
'L_NEW_CATEGORY' 					=> 'Nowa kategoria',
'L_FOR_SELECTION' 					=> 'Wybrane pozycje...',
'L_CAT_APPLY_BUTTON'				=> 'Zapisz zmiany',
'L_CAT_UNKNOWN'						=> 'Nieznana kategoria',

# categorie.php

'L_EDITCAT_PAGE_TITLE'				=> 'Edycja opcji kategorii',
'L_EDITCAT_DESCRIPTION'				=> 'Opis',
'L_EDITCAT_DISPLAY_HOMEPAGE'		=> 'Pokaż artykuły z tej kategorii na stronie głównej',
'L_EDITCAT_TEMPLATE'				=> 'Szablon',
'L_EDITCAT_BACK_TO_PAGE'			=> 'Przejdż do listy kategorii',
'L_EDITCAT_UPDATE'					=> 'Zapisz zmiany',
'L_EDITCAT_TITLE_HTMLTAG'			=> 'Zawartość tagu "tytułu" (opcjonalnie)',
'L_EDITCAT_META_DESCRIPTION'		=> 'Zawartość tagu "opisu" (opcjonalnie)',
'L_EDITCAT_META_KEYWORDS'			=> 'Zawartość tagu "słowa kluczowego" (opcjonalnie)',

# commentaire.php

'L_COMMENT_ORPHAN' 					=> 'brak komentarza',
'L_COMMENT_ORPHAN_STATUS' 			=> 'Nie jest wyświetlany (radzimy usunąć ten komentarz)',
'L_COMMENT_ARTICLE_LINKED'			=> 'Artykuł',
'L_COMMENT_ARTICLE_LINKED_TITLE'	=> 'Edytuj artykuł z tego komentarza',
'L_COMMENT_OFFLINE' 				=> 'Nieaktywne',
'L_COMMENT_ONLINE'					=> 'Aktywne',
'L_COMMENT_ONLINE_TITLE'			=> 'Przejdż do tego komentarza',
'L_BACK_TO_ARTICLE_COMMENTS'		=> 'Przejdż do listy komentarzy z tego artykułu',
'L_BACK_TO_COMMENTS'        		=> 'Przejdż do listy komentarzy',
'L_COMMENT_EDITING' 				=> 'Edytuj komentarz',
'L_COMMENT_AUTHOR_FIELD'			=> 'Autor',
'L_COMMENT_TYPE_FIELD'				=> 'Typ komentarza',
'L_COMMENT_DATE_FIELD'				=> 'Data i czas publikacji',
'L_COMMENT_IP_FIELD'				=> 'IP',
'L_COMMENT_SITE_FIELD'				=> 'Strona',
'L_COMMENT_EMAIL_FIELD'				=> 'E-mail',
'L_COMMENT_STATUS_FIELD'			=> 'Status',
'L_COMMENT_LINKED_ARTICLE_FIELD'	=> 'Dołączony artykuł',
'L_COMMENT_ARTICLE_FIELD'			=> 'Komentarz',
'L_COMMENT_DELETE_CONFIRM'			=> 'Usunąć ten komentarz ?',
'L_COMMENT_PUBLISH_BUTTON'			=> 'Zatwierdz',
'L_COMMENT_OFFLINE_BUTTON'			=> 'Zdeaktywuj',
'L_COMMENT_ANSWER_BUTTON'			=> 'Odpowiedź na komentarz',
'L_COMMENT_UPDATE_BUTTON'			=> 'Zaktualizuj',
'L_COMMENT_WRITTEN_BY'				=> 'Napisane przez',
'L_ERR_CATEGORY_ALREADY_EXISTS'		=> 'Nazwa kategorii jest zajęta',

# sous_navigation/commentaires.php

'L_COMMENT_NEW_COMMENT_TITLE'		=> 'Dodaj nowy komentarz do tego artykułu',
'L_COMMENT_NEW_COMMENT'				=> 'Dodaj nowy komentarz',

# commentaire_new.php

'L_ERR_ANSWER_UNKNOWN_COMMENT'		=> 'Próbujesz odpowiedzieć na komentarz który nie istnieje lub jest niepoprawny',
'L_ERR_ANSWER_OFFLINE_COMMENT'		=> 'Komentarz jest nieaktywny, nie można na niego odpowiedzieć !',
'L_ERR_COMMENT_UNKNOWN_ARTICLE'		=> 'Artykuł nie istnieje, niemożliwe jest napisanie komentarza !',
'L_ERR_CREATING_COMMENT'			=> 'Wystąpił błąd podczas tworzenia komentarza',
'L_CREATING_COMMENT_SUCCESSFUL'		=> 'Komentarz pomyślnie utworzono',
'L_CREATE_NEW_COMMENT'				=> 'Odpowiedź na komentarz',
'L_COMMENT_SAVE_BUTTON' 			=> 'Napisz',
'L_ARTICLE_COMMENTS_LIST'			=> 'Komentarze do tego artukułu',
'L_COMMENT_ANSWER_TITLE' 			=> 'Odpowiedź na ten komentarz',
'L_COMMENT_ANSWER'					=> 'Odpowiedź',

# comments.php

'L_COMMENTS_ARTICLE_SCOPE' 			=> 'Artykuł',
'L_COMMENTS_GLOBAL_SCOPE'			=> 'cała strona',
'L_COMMENTS_LIST_DATE'				=> 'Data',
'L_COMMENTS_LIST_AUTHOR'			=> 'Autor',
'L_COMMENTS_LIST_MESSAGE'			=> 'Wiadomość',
'L_COMMENTS_LIST_ACTION'			=> 'Działanie',
'L_COMMENT_EDIT'					=> 'Edytuj',
'L_COMMENT_EDIT_TITLE'				=> 'Edytuj ten komentarz',
'L_COMMENT_DELETE'					=> 'Usuń',
'L_COMMENT_OFFLINE_FEEDS_TITLE'		=> 'Kanał RSS dla komentarzy w trybie offline',
'L_COMMENT_OFFLINE_FEEDS'			=> 'Komentarze nieaktywne',
'L_COMMENT_ONLINE_FEEDS_TITLE'		=> 'Kanał RSS dla komentarzy w trybie online',
'L_COMMENT_ONLINE_FEEDS'			=> 'Komentarze aktywne',
'L_COMMENTS_PRIVATE_FEEDS'		    => 'Prywatne kanały',
'L_COMMENTS_ONLINE_LIST'			=> 'Lista opublikowanych komentarzy',
'L_COMMENTS_OFFLINE_LIST'			=> 'Lista komentarzy oczekujących na zatwierdzenie',
'L_COMMENTS_ALL_LIST'				=> 'Lista komentarzy',
'L_COMMENT_SET_ONLINE'				=> 'Aktywuj komentarz',
'L_COMMENT_SET_OFFLINE'				=> 'Zdeaktywuj komentarz',

# index.php

'L_SEARCH'							=> 'Szukaj',
'L_SEARCH_PLACEHOLDER'				=> 'id lub tytuł',
'L_ARTICLES_ALL_CATEGORIES'			=> 'Wszystkie kategorie...',
'L_ALL'								=> 'Wszystkie',
'L_ALL_PUBLISHED'					=> 'Opublikowane',
'L_ALL_DRAFTS'						=> 'Projekty',
'L_ALL_AWAITING_MODERATION'			=> 'Oczekiwanie na zatwierdzenie',
'L_ARTICLES_FILTER_BUTTON'			=> 'Filtr',
'L_CATEGORIES_TABLE'				=> 'Kategorie',
'L_SPECIFIC_CATEGORIES_TABLE'		=> 'Konkretne kategorie',
'L_ALL_ARTICLES_CATEGORIES_TABLE'	=> 'Wszystkie posty',
'L_ARTICLES_LIST'					=> 'Lista postów',
'L_ARTICLE_LIST_DATE'				=> 'Data',
'L_ARTICLE_LIST_TITLE'				=> 'Tytuł',
'L_ARTICLE_LIST_CATEGORIES'			=> 'Kategoria',
'L_ARTICLE_LIST_NBCOMS'				=> 'Nr komentarzy',
'L_ARTICLE_LIST_AUTHOR'				=> 'Autor',
'L_ARTICLE_LIST_ACTION'				=> 'Akcja',
'L_CATEGORY_HOME'					=> 'Start',
'L_CATEGORY_DRAFT'					=> 'Projekt',
'L_ARTICLE_VIEW_TITLE'				=> 'Zobacz ten post na stronie',
'L_ARTICLE_EDIT'					=> 'Edytuj',
'L_ARTICLE_EDIT_TITLE'				=> 'Edytuj ten post',
'L_NEW_COMMENTS_TITLE' 				=> 'Komentarze oczekujące na zatwierdzenie',
'L_VALIDATED_COMMENTS_TITLE' 		=> 'Komentarze zatwierdzone',
'L_NO_ARTICLE'						=> 'Brak postów',

# medias.php

'L_MEDIAS_FILENAME'					=> 'Nazwa pliku',
'L_MEDIAS_TITLE'					=> 'Zarządzanie mediami',
'L_MEDIAS_DIRECTORY' 				=> 'lokalizacja',
'L_MEDIAS_BACK'						=> 'Powrót do mediów',
'L_MEDIAS_MAX_UPOLAD_FILE'			=> 'Maksymalny rozmiar pliku',
'L_MEDIAS_MAX_POST_SIZE'			=> 'Maksymalny rozmiar danych',
'L_MEDIAS_SUBMIT_FILE'				=> 'Wysłać',
'L_MEDIAS_IMAGES'					=> 'Obrazowość',
'L_MEDIAS_DOCUMENTS'				=> 'Dokumenty',
'L_MEDIAS_ADD_FILE'					=> 'Dodawanie plików',
'L_MEDIAS_DELETE_FOLDER'			=> 'Usunąć',
'L_MEDIAS_DELETE_FOLDER_CONFIRM'	=> 'Usuń folder %s i jego zawartość ?',
'L_MEDIAS_FOLDER'					=> 'Rekord',
'L_MEDIAS_NEW_FOLDER'				=> 'Nowy folder',
'L_MEDIAS_CREATE_FOLDER'			=> 'Tworzyć',
'L_MEDIAS_FILESIZE'					=> 'Rozmiar',
'L_MEDIAS_DATE'						=> 'Data',
'L_MEDIAS_DIMENSIONS'				=> 'Wymiary',
'L_MEDIAS_NO_FILE'					=> 'żaden plik',
'L_MEDIAS_RESIZE'					=> 'Zmiana rozmiaru zdjęcia',
'L_MEDIAS_RESIZE_NO'				=> 'Oryg',
'L_MEDIAS_THUMBS'					=> 'Tworzenie miniaturek',
'L_MEDIAS_THUMBS_NONE'				=> 'Nie miniatura',
'L_MEDIAS_MODIFY'					=> 'Zmiana',
'L_MEDIAS_THUMB'					=> 'Miniatura',
'L_MEDIAS_EXTENSION'				=> 'Przedłużenie',
'L_MEDIAS_ADD'						=> 'Dodać',
'L_MEDIAS_ALIGNMENT'				=> 'Wyrównanie',
'L_MEDIAS_ALIGN_NONE'				=> 'Nie',
'L_MEDIAS_ALIGN_LEFT'				=> 'Lewo',
'L_MEDIAS_ALIGN_CENTER'				=> 'Centrum',
'L_MEDIAS_ALIGN_RIGHT'				=> 'Prawo',
'L_MEDIAS_RECREATE_THUMB'			=> 'Odtworzyć miniatury',
'L_MEDIAS_LINK_COPYCLP'             => 'Skopiuj link do schowka',
'L_MEDIAS_LINK_COPYCLP_ERR'         => 'Nie można skopiować link do schowka',
'L_MEDIAS_LINK_COPYCLP_DONE'        => 'Link został skopiowany',
'L_MEDIAS_NEW_NAME'					=> 'Nowe imie',
'L_MEDIAS_RENAME'					=> 'Przemianować',

# parametres_affichage.php

'L_CONFIG_VIEW_FIELD'				=> 'Opcje wyświetlania',
'L_CONFIG_VIEW_SKIN_SELECT'			=> 'Wybierz szablon',
'L_CONFIG_VIEW_FILES_EDIT_TITLE'	=> 'Edycja plików z szablonu',
'L_CONFIG_VIEW_FILES_EDIT'			=> 'Edytuj szablon',
'L_CONFIG_VIEW_SORT'				=> 'Tri des articles',
'L_CONFIG_VIEW_BYPAGE'				=> 'Nombre d\'articles affichés par page',
'L_CONFIG_VIEW_BYPAGE_ARCHIVES'		=> 'Nombre d\'articles affichés par page dans les archives',
'L_CONFIG_VIEW_BYPAGE_TAGS'			=> 'Artykuły na stronie w tagach',
'L_CONFIG_VIEW_BYPAGE_ADMIN'		=> 'Nombre d\'articles affichés par page dans l\'administration',
'L_CONFIG_VIEW_SORT_COMS'			=> 'Tri des commentaires',
'L_CONFIG_VIEW_BYPAGE_ADMIN_COMS'	=> 'Nombre de commentaires affichés par page dans l\'administration',
'L_CONFIG_VIEW_IMAGES'				=> 'Taille des images (largeur x hauteur)',
'L_CONFIG_VIEW_THUMBS'				=> 'Taille des miniatures (largeur x hauteur)',
'L_CONFIG_VIEW_HOMESTATIC'			=> 'Utiliser une page statique comme page d\'accueil',
'L_CONFIG_VIEW_HOMESTATIC_ACTIVE'	=> 'Attention cette page est inactive',
'L_CONFIG_VIEW_PLUXML_RESSOURCES'	=> 'Télécharger d\'autres thèmes sur <a href="http://ressources.pluxml.org">ressources.pluxml.org</a>.',
'L_CONFIG_VIEW_BYPAGE_FEEDS'		=> 'Nombre d\'articles/commentaires affichés sur les fils Rss',
'L_CONFIG_VIEW_FEEDS_HEADLINE'		=> 'Afficher uniquement le chapô dans les flux Rss des articles',
'L_CONFIG_VIEW_FEEDS_HEADLINE_HELP'	=> 'Si le chapô est vide, le contenu est affiché',
'L_CONFIG_VIEW_FEEDS_FOOTER'		=> 'Texte à ajouter comme signature au bas de chaque flux Rss des articles',
'L_CONFIG_VIEW_UPDATE'				=> 'Modifier les options d\'affichage',
'L_CONFIG_VIEW_DISPLAY_EMPTY_CAT'	=> 'Afficher les catégories sans article',
'L_CONFIG_HOMETEMPLATE'				=> 'Template de la page d\'accueil',

# parametres_avances.php

'L_CONFIG_ADVANCED_DESC'			=> 'Configuration avancée',
'L_CONFIG_ADVANCED_URL_REWRITE'		=> 'Activer la réécriture d\'urls',
'L_CONFIG_ADVANCED_URL_REWRITE_ALERT'=> 'Attention un fichier .htaccess est déjà présent à la racine de votre PluXml. En activant la réécriture d\'url ce fichier sera modifié',
'L_CONFIG_ADVANCED_GZIP'			=> 'Activer la compression GZIP',
'L_CONFIG_ADVANCED_GZIP_HELP'		=> 'Permet de compresser les pages pour économiser de la bande passante, cependant cela peut augmenter la charge processeur',
'L_CONFIG_ADVANCED_CAPCHA'			=> 'Activer le capcha anti-spam',
'L_CONFIG_ADVANCED_ADMIN_KEY'		=> 'Clef d\'administration (URLs privés)',
'L_CONFIG_ADVANCED_KEY_HELP'		=> 'Vider ce champs pour régénérer la clef',
'L_CONFIG_ADVANCED_USERFOLDERS'		=> 'Utiliser un dossier medias différent pour chaque utilisateur',
'L_HELP_SLASH_END'					=> 'Ne pas oublier le slash à la fin',
'L_CONFIG_ADVANCED_MEDIAS_FOLDER'	=> 'Emplacement des médias (dossier)',
'L_CONFIG_ADVANCED_ARTS_FOLDER'		=> 'Emplacement des articles (dossier)',
'L_CONFIG_ADVANCED_COMS_FOLDER'		=> 'Emplacement des commentaires (dossier)',
'L_CONFIG_ADVANCED_STATS_FOLDER'	=> 'Emplacement des pages statiques (dossier)',
'L_CONFIG_ADVANCED_THEMES_FOLDER'	=> 'Emplacement des thèmes (dossier)',
'L_CONFIG_ADVANCED_PLUGINS_FOLDER'	=> 'Emplacement des plugins (dossier)',
'L_CONFIG_ADVANCED_CONFIG_FOLDER'	=> 'Emplacement des fichiers de configuration (dossier)',
'L_CONFIG_ADVANCED_UPDATE'			=> 'Modifier la configuration avancée',
'L_CONFIG_CUSTOM_CSSADMIN_PATH'		=> 'Emplacement et nom du fichier css personnel pour la personnalisation de l\'interface d\'administration (option)',

# parametres_base.php

'L_CONFIG_BASE_CONFIG_TITLE'		=> 'Podstawowa konfiguracja',
'L_CONFIG_BASE_SITE_TITLE'			=> 'Tytuł strony',
'L_CONFIG_BASE_SITE_SLOGAN'			=> 'Opis / slogan strony',
'L_CONFIG_BASE_URL_HELP'			=> 'Nie zapomnij o ukośniku na końcu',
'L_CONFIG_BASE_DEFAULT_LANG'		=> 'Domyślny język strony',
'L_CONFIG_BASE_TIMEZONE'			=> 'Strefa czasowa',
'L_CONFIG_BASE_ALLOW_COMMENTS'		=> 'Pokaż komentarze',
'L_CONFIG_BASE_MODERATE_COMMENTS'	=> 'Podstawowa konfiguracja edycji komentarzy',
'L_CONFIG_BASE_MODERATE_ARTICLES'	=> 'Podstawowa konfiguracja edycji postów',
'L_CONFIG_BASE_UPDATE'				=> 'Zapisz zmiany',
'L_CONFIG_META_DESCRIPTION'			=> 'Zawartość tagu "opisu" strony (opcjonalnie)',
'L_CONFIG_META_KEYWORDS'			=> 'Zawartość tagu "słowa kluczowego" strony (opcjonalnie)',

# parametres_edittpl.php

'L_CONFIG_EDITTPL_ERROR_NOTHEME'	=> 'Ten szablon nie istnieje!',
'L_CONFIG_EDITTPL_TITLE'			=> 'Edycja szablonu',
'L_CONFIG_EDITTPL_SELECT_FILE'		=> 'Wybierz plik, który ma być edytowany: ',
'L_CONFIG_EDITTPL_LOAD'				=> 'Zmień',

# parametres_infos.php

'L_CONFIG_INFOS_TITLE'				=> 'Informations relatives à PluXml',
'L_CONFIG_INFOS_DESCRIPTION'		=> 'Ces informations vous renseignent sur le fonctionnement de votre PluXml et peuvent s\'avérer utiles pour son dépannage.',
'L_CONFIG_INFOS_NB_CATS'			=> 'Nombre de catégories :',
'L_CONFIG_INFOS_NB_STATICS'			=> 'Nombre de pages statiques :',
'L_CONFIG_INFOS_WRITER'				=> 'Nom du rédacteur en session :',
'L_PLUXML_CHECK_VERSION'			=> 'Vérification du numéro de version de PluXml sur le site officiel PluXml.org',
'L_PLUXML_UPDATE_UNAVAILABLE'		=> 'Impossible de vérifier les mises à jour tant que \'allow_url_fopen\' est désactivé sur ce système',
'L_PLUXML_UPDATE_ERR'				=> 'La vérification de mise à jour a échoué pour une raison inconnue',
'L_PLUXML_UPTODATE'					=> 'Vous utilisez la dernière version de PluXml',
'L_PLUXML_UPDATE_AVAILABLE'			=> 'Une nouvelle version de PluXml est sortie ! Vous pouvez la télécharger sur',

# parametres_users.php

'L_CONFIG_USERS_TITLE'				=> 'Gestion des utilisateurs',
'L_CONFIG_USER'						=> 'utilisateur',
'L_CONFIG_USERS_ID'					=> 'Identifiant',
'L_CONFIG_USERS_ACTIVE'				=> 'Actif',
'L_CONFIG_USERS_ACTION'				=> 'Action',
'L_CONFIG_USERS_NEW'				=> 'Nouvel utilisateur',
'L_CONFIG_USERS_UPDATE'				=> 'Modifier la liste des utilisateurs',
'L_ERR_LOGIN_ALREADY_EXISTS'		=> 'Identifiant de connexion déjà utilisé',
'L_ERR_USERNAME_ALREADY_EXISTS'		=> 'Nom d\'utilisateur déjà utilisé',

# parametre_plugins.php

'L_BACK_TO_PLUGINS'					=> 'Retour à la page des plugins',
'L_NO_PLUGIN'						=> 'Aucun plugin',
'L_PLUGIN_NO_CONFIG'				=> 'Plugin non configuré',
'L_PLUGINS_CSS'						=> 'Code css',
'L_PLUGINS_CSS_TITLE'				=> 'Éditer le code css du plugin',
'L_CONTENT_FIELD_FRONTEND'			=> 'Contenu fichier css site',
'L_CONTENT_FIELD_BACKEND'			=> 'Contenu fichier css administrateur',

# parametres_plugins.php

'L_PLUGINS_TITLE'					=> 'Gestion des plugins',
'L_PLUGINS_VERSION'					=> 'Version',
'L_PLUGINS_AUTHOR'					=> 'Autor',
'L_PLUGINS_ACTIVATE'				=> 'Activer',
'L_PLUGINS_DEACTIVATE'				=> 'Désactiver',
'L_PLUGINS_DELETE'					=> 'Supprimer',
'L_PLUGINS_DELETE_ERROR'			=> 'Une erreur s\'est produite pendant la suppression',
'L_PLUGINS_DELETE_SUCCESSFUL'		=> 'Suppression effectuée avec succès',
'L_PLUGINS_CONFIG'					=> 'Configuration',
'L_PLUGINS_CONFIG_TITLE'			=> 'Configuration du plugin',
'L_PLUGINS_HELP'					=> 'Pomoc',
'L_PLUGINS_HELP_TITLE'				=> 'Patrz Korzystanie z wtyczki',
'L_PLUGINS_REQUIREMENTS'			=> 'Pré-requis',
'L_PLUGINS_REQUIREMENTS_HELP'		=> 'Liste des plugins présents et actifs pour activer ce plugin',
'L_PLUGINS_REQUIREMENTS_NONE'		=> 'Aucun',
'L_PLUGINS_ALPHA_SORT'				=> 'Trier par ordre alphabétique les plugins',
'L_PLUGINS_LOADING_SORT'			=> 'Ordre de chargement',
'L_PLUGINS_ACTION'					=> 'Action',
'L_PLUGINS_APPLY_BUTTON'			=> 'Modifier la liste des plugins',
'L_PLUGINS_ACTIVE_LIST'				=> 'Plugins actifs',
'L_PLUGINS_INACTIVE_LIST'			=> 'Plugins inactifs',

# profil.php

'L_PROFIL_EDIT_TITLE'				=> 'Edytuj profil',
'L_PROFIL'							=> 'Profil',
'L_PROFIL_LOGIN'					=> 'Zalogowany jako',
'L_PROFIL_USER'						=> 'Nazwa użytkownika',
'L_PROFIL_MAIL'						=> 'Adres e-mail',
'L_PROFIL_ADMIN_LANG'				=> 'Język używany w administracji',
'L_PROFIL_INFOS'					=> 'Informacja',
'L_PROFIL_UPDATE'					=> 'Zapisz zmiany',
'L_PROFIL_CHANGE_PASSWORD'			=> 'Zmiana hasła',
'L_PROFIL_PASSWORD'					=> 'Hasło',
'L_PROFIL_CONFIRM_PASSWORD'			=> 'Powtórz hasło',
'L_PROFIL_UPDATE_PASSWORD'			=> 'Zmień hasło',

# statique.php

'L_STATIC_BACK_TO_PAGE'				=> 'Przejdź do listy stron statycznych',
'L_STATIC_UNKNOWN_PAGE'				=> 'Ta strona nie istnieje już !',
'L_STATIC_TITLE'					=> 'Edytuj kodu źródłowego',
'L_STATIC_VIEW_PAGE'				=> 'Przeglądnij',
'L_STATIC_ON_SITE'					=> 'strona',
'L_STATIC_UPDATE'					=> 'Zapisz zmiany',
'L_STATIC_TITLE_HTMLTAG'			=> 'Zawartość tagu "tytułu" (opcjonalnie)',
'L_STATIC_META_DESCRIPTION'			=> 'Zawartość tagu "opisu" (opcjonalnie)',
'L_STATIC_META_KEYWORDS'			=> 'Zawartość tagu "słowa kluczowe" (opcjonalnie)',

# statiques.php

'L_STATICS_PAGE_TITLE'				=> 'Utwórz lub edytuj strone statyczną',
'L_STATICS_ID'						=> 'ID',
'L_STATICS_GROUP'					=> 'Grupa',
'L_STATICS_TITLE'					=> 'Tytuł',
'L_STATICS_URL'						=> 'URL',
'L_STATICS_ACTIVE'					=> 'Aktywna',
'L_STATICS_ORDER'					=> 'Kolejność',
'L_STATICS_MENU'					=> 'Menu',
'L_STATICS_ACTION'					=> 'Akcja',
'L_STATICS_TEMPLATE_FIELD'			=> 'Szablon',
'L_STATICS_PAGE_HOME'				=> 'Ustaw jako stronę główną',
'L_STATICS_HOME_PAGE' 			 	=> 'Strona główna',
'L_PAGE'							=> 'strona',
'L_VIEW'							=> 'Podgląd',
'L_STATICS_SRC_TITLE'				=> 'Edytuj kod źródłowy strony',
'L_STATICS_SRC'						=> 'Edycja',
'L_STATICS_NEW_PAGE'				=> 'Nowa strona',
'L_STATICS_UPDATE'					=> 'Zapisz zmiany',
'L_ERR_STATIC_ALREADY_EXISTS'		=> 'Strona o tym tytule już istnieje',

# top.php
'L_PROFIL_ADMIN'					=> 'Administrator',
'L_PROFIL_MANAGER'					=> 'Menedżer',
'L_PROFIL_MODERATOR'				=> 'Moderator',
'L_PROFIL_EDITOR'					=> 'Edytor',
'L_PROFIL_WRITER'					=> 'Redaktor',
'L_ADMIN'							=> 'Administracja',
'L_LOGIN'							=> 'Login',
'L_ADMIN_LOGOUT'					=> 'Wyloguj',
'L_ADMIN_LOGOUT_TITLE'				=> 'Opuść panel administracyjny',
'L_BACK_TO_SITE'					=> 'Strona główna',
'L_BACK_TO_SITE_TITLE'				=> 'Przejdż do strony głównej',
'L_BACK_TO_BLOG'					=> 'Blog',
'L_BACK_TO_BLOG_TITLE'				=> 'Przejdż do strony bloga',
'L_MENU_ARTICLES'					=> 'Artykuły',
'L_MENU_ARTICLES_TITLE'				=> 'Lista i edytor artykułów',
'L_MENU_NEW_ARTICLES'				=> 'Napisz nowy artykuł',
'L_MENU_NEW_ARTICLES_TITLE'			=> 'Nowy artykuł',
'L_MENU_STATICS_TITLE'				=> 'Lista i edytor stron statycznych',
'L_MENU_STATICS'					=> 'Strony statyczne',
'L_MENU_COMMENTS_TITLE'				=> 'Lista i edytor komentarzy',
'L_MENU_COMMENTS'					=> 'Komentarze',
'L_MENU_MEDIAS_TITLE'				=> 'Dodaj i zarządzaj materiałami',
'L_MENU_MEDIAS'						=> 'Media',
'L_MENU_CATEGORIES_TITLE'			=> 'Lista i edytor kategorii',
'L_MENU_CATEGORIES'					=> 'Kategorie',
'L_MENU_CONFIG_TITLE'				=> 'Skonfiguruj PluXml',
'L_MENU_CONFIG'						=> 'Ustawienia',
'L_MENU_PROFIL_TITLE'				=> 'Zarządzaj profilami użytkowników',
'L_MENU_PROFIL'						=> 'Profil',
'L_WARNING_INSTALLATION_FILE'		=> 'Plik install.php znajduje się w katalogu głównym PluXml. <br />Ze względów bezpieczeństwa zaleca się, aby go <a class="lnkdelete" href="?del=install">usunąć</a>.',

# user.php
'L_USER_UNKNOWN'					=> 'Nieznany użytkownik',
'L_USER_LANG'						=> 'Język używany w administracji',
'L_USER_MAIL'						=> 'Adres e-mail',
'L_USER_INFOS'						=> 'Informacja',
'L_USER_UPDATE'						=> 'Zapisz zmiany',
'L_USER_PAGE_TITLE'					=> 'Edycja użytkownika',
'L_USER_BACK_TO_PAGE'				=> 'Przejdź do listy użytkowników',

#

'L_MENU_CONFIG_BASE_TITLE'			=> 'Podstawowa edycja konfiguracji PluXml',
'L_MENU_CONFIG_BASE'				=> 'Podstawowa konfiguracja',
'L_MENU_CONFIG_VIEW_TITLE'			=> 'Zmiana opcji wyświetlania PluXml',
'L_MENU_CONFIG_VIEW'				=> 'Opcje wyświetlania',
'L_MENU_CONFIG_USERS_TITLE'			=> 'Zarządzanie kontami użytkowników PluXml',
'L_MENU_CONFIG_USERS'				=> 'Konta użytkowników',
'L_MENU_CONFIG_ADVANCED_TITLE'		=> 'Zaawansowana edycja konfiguracji PluXml',
'L_MENU_CONFIG_ADVANCED'			=> 'Zaawansowana konfiguracja',
'L_MENU_CONFIG_INFOS_TITLE'			=> 'Informacja na temat PluXml',
'L_MENU_CONFIG_INFOS'				=> 'Informacja',
'L_MENU_CONFIG_PLUGINS_TITLE'		=> 'Zarządzanie wtyczkami',
'L_MENU_CONFIG_PLUGINS'				=> 'Plugins',
'L_THEMES'							=> 'Tematy',
'L_THEMES_TITLE'					=> 'Zarządzanie tematy',
'L_HELP'							=> 'Pomoc',
'L_HELP_TITLE'						=> 'Zobacz pomoc',
'L_BACK_TO_THEMES'					=> 'Powrót do tematów strony',
'L_CONFIG_THEME_UPDATE'				=> 'Zmień styl',
);
?>
